@@ -1,5 +1,5 @@
 """
- * $Id: 1.1+2 utils.py 7df57bbd15f8 2021-05-19 od $
+ * $Id: 1.1+3 utils.py e48fa1383c14 2021-05-19 od $
  *
  * This file is part of the Cloud Services Integration Platform (CSIP),
  * a Model-as-a-Service framework, API and application suite.
@@ -674,10 +674,15 @@ class Client(object):
         return self.metainfo.get(self.META_KEY_MODE, self.META_VAL_SYNC) == self.META_VAL_ASYNC
 
     def is_finished(self) -> bool:
-        """Check if execution mode is async """
+        """Check if execution finished """
         return self.http_status == 200 and self.metainfo.get(
             self.META_KEY_STATUS, self.STATUS_UNKNOWN) == self.STATUS_FINISHED
 
+    def is_failed(self) -> bool:
+        """Check if service failed """
+        return self.http_status == 200 and self.metainfo.get(
+            self.META_KEY_STATUS, self.STATUS_UNKNOWN) == self.STATUS_FAILED
+
     def get_first_poll(self) -> int:
         return self.metainfo.get(self.META_KEY_FIRST_POLL, 2000)
 
